@@ -1,7 +1,9 @@
 from django.db import transaction
 from rest_framework import exceptions
 from rest_framework.serializers import (
+    BooleanField,
     CharField,
+    ChoiceField,
     DateField,
     FloatField,
     IntegerField,
@@ -19,6 +21,16 @@ class QuestionJexlField(serializers.JexlField):
         super().__init__(QuestionJexl(), **kwargs)
 
 
+class ButtonActionField(ChoiceField):
+    def __init__(self, **kwargs):
+        super().__init__(models.Question.ACTION_CHOICES, **kwargs)
+
+
+class ButtonColorField(ChoiceField):
+    def __init__(self, **kwargs):
+        super().__init__(models.Question.COLOR_CHOICES, **kwargs)
+
+
 class SaveFormSerializer(serializers.ModelSerializer):
     class Meta:
         model = models.Form
@@ -51,7 +63,12 @@ class AddFormQuestionSerializer(serializers.ModelSerializer):
         # default sort is 0, as per default form question are sorted
         # in descending order this will be at the end
         _, created = models.FormQuestion.objects.get_or_create(
-            form=self.instance, question=validated_data["question"]
+            form=self.instance,
+            question=validated_data["question"],
+            defaults={
+                "created_by_user": self.context["request"].user.username,
+                "created_by_group": self.context["request"].user.group,
+            },
         )
 
         if created:
@@ -442,6 +459,29 @@ class SaveCalculatedFloatQuestionSerializer(SaveQuestionSerializer):
         ]
 
 
+class SaveActionButtonQuestionSerializer(SaveQuestionSerializer):
+    action = ButtonActionField(required=True)
+    color = ButtonColorField(required=True)
+    validate_on_enter = BooleanField(required=True)
+
+    def validate(self, data):
+        data["type"] = models.Question.TYPE_ACTION_BUTTON
+        return super().validate(data)
+
+    class Meta(SaveQuestionSerializer.Meta):
+        fields = [
+            "label",
+            "slug",
+            "info_text",
+            "is_hidden",
+            "meta",
+            "is_archived",
+            "action",
+            "color",
+            "validate_on_enter",
+        ]
+
+
 class SaveOptionSerializer(serializers.ModelSerializer):
     class Meta:
         fields = ["slug", "label", "is_archived", "meta"]
