@@ -2,7 +2,6 @@ from django.core.exceptions import ValidationError
 from django.db import transaction
 from rest_framework import exceptions
 from rest_framework.serializers import CharField, JSONField, ListField
-from simple_history.utils import bulk_create_with_history
 
 from caluma.caluma_core.events import SendEventSerializerMixin
 
@@ -40,7 +39,7 @@ class GroupJexlField(serializers.JexlField):
 class SaveWorkflowSerializer(serializers.ModelSerializer):
     class Meta:
         model = models.Workflow
-        fields = (
+        fields = [
             "slug",
             "name",
             "description",
@@ -50,7 +49,7 @@ class SaveWorkflowSerializer(serializers.ModelSerializer):
             "allow_forms",
             "is_archived",
             "is_published",
-        )
+        ]
 
 
 class AddWorkflowFlowSerializer(serializers.ModelSerializer):
@@ -82,15 +81,14 @@ class AddWorkflowFlowSerializer(serializers.ModelSerializer):
             created_by_user=user.username,
             created_by_group=user.group,
         )
-        task_flows = [
-            models.TaskFlow(task=task, workflow=instance, flow=flow) for task in tasks
-        ]
-        bulk_create_with_history(task_flows, models.TaskFlow)
+
+        for task in tasks:
+            models.TaskFlow.objects.create(task=task, workflow=instance, flow=flow)
 
         return instance
 
     class Meta:
-        fields = ("workflow", "tasks", "next")
+        fields = ["workflow", "tasks", "next"]
         model = models.Workflow
 
 
@@ -102,7 +100,7 @@ class RemoveFlowSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("flow",)
+        fields = ["flow"]
         model = models.Flow
 
 
@@ -121,7 +119,7 @@ class SaveTaskSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = models.Task
-        fields = (
+        fields = [
             "slug",
             "name",
             "description",
@@ -131,7 +129,7 @@ class SaveTaskSerializer(serializers.ModelSerializer):
             "is_archived",
             "lead_time",
             "is_multiple_instance",
-        )
+        ]
 
 
 class SaveSimpleTaskSerializer(SaveTaskSerializer):
@@ -162,7 +160,7 @@ class SaveCompleteTaskFormTaskSerializer(SaveTaskSerializer):
         return super().validate(data)
 
     class Meta(SaveTaskSerializer.Meta):
-        fields = SaveTaskSerializer.Meta.fields + ("form",)
+        fields = SaveTaskSerializer.Meta.fields + ["form"]
 
 
 class CaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
@@ -198,7 +196,7 @@ class CaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
     class Meta:
         model = models.Case
-        fields = ("workflow", "meta", "parent_work_item", "form", "context")
+        fields = ["workflow", "meta", "parent_work_item", "form", "context"]
 
 
 class SaveCaseSerializer(CaseSerializer):
@@ -221,7 +219,7 @@ class SaveCaseSerializer(CaseSerializer):
         return instance
 
     class Meta(CaseSerializer.Meta):
-        fields = ("id", "workflow", "meta", "parent_work_item", "form", "context")
+        fields = ["id", "workflow", "meta", "parent_work_item", "form", "context"]
 
 
 class CancelCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
@@ -229,7 +227,7 @@ class CancelCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
     class Meta:
         model = models.Case
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
     def validate(self, data):
         try:
@@ -260,7 +258,7 @@ class SuspendCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
     class Meta:
         model = models.Case
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
     def validate(self, data):
         try:
@@ -291,7 +289,7 @@ class ResumeCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
     class Meta:
         model = models.Case
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
     def validate(self, data):
         try:
@@ -347,7 +345,7 @@ class CompleteWorkItemSerializer(ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
 
 class SkipWorkItemSerializer(ContextModelSerializer):
@@ -378,7 +376,7 @@ class SkipWorkItemSerializer(ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
 
 class CancelWorkItemSerializer(ContextModelSerializer):
@@ -409,7 +407,7 @@ class CancelWorkItemSerializer(ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
 
 class SaveWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer):
@@ -440,7 +438,7 @@ class SaveWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = (
+        fields = [
             "work_item",
             "name",
             "description",
@@ -448,7 +446,7 @@ class SaveWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer):
             "deadline",
             "meta",
             "context",
-        )
+        ]
 
 
 class CreateWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer):
@@ -518,7 +516,7 @@ class CreateWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer)
 
     class Meta:
         model = models.WorkItem
-        fields = (
+        fields = [
             "case",
             "multiple_instance_task",
             "name",
@@ -529,7 +527,7 @@ class CreateWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer)
             "deadline",
             "meta",
             "context",
-        )
+        ]
 
 
 class SuspendWorkItemSerializer(ContextModelSerializer):
@@ -560,7 +558,7 @@ class SuspendWorkItemSerializer(ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = ("id", "context")
+        fields = ["id", "context"]
 
 
 class ResumeWorkItemSerializer(ContextModelSerializer):
@@ -591,4 +589,4 @@ class ResumeWorkItemSerializer(ContextModelSerializer):
 
     class Meta:
         model = models.WorkItem
-        fields = ("id", "context")
+        fields = ["id", "context"]
